@@ -13,16 +13,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #ifndef __CONVOLVE_H__
 #define __CONVOLVE_H__
 
+#include "paint_core.h"
+#include "procedural_db.h"
 #include "tools.h"
 
-void          convolve_dialog      (void);
-void *        convolve_paint_func  (Tool *, int);
+void *        convolve_paint_func  (PaintCore *, GimpDrawable *, int);
 Tool *        tools_new_convolve   (void);
 void          tools_free_convolve  (Tool *);
 
+/*  Procedure definition and marshalling function  */
+extern ProcRecord convolve_proc;
+
 #endif  /*  __CONVOLVE_H__  */
